@@ -31,6 +31,30 @@ public class Screen extends Surface
 	**/
 	public static native void setGammaRamp(int[] redtable, int[] greentable, int[] bluetable);
 
+	/**
+	* SDL_SetGammaRamp(redTable, null, null)
+	**/
+	public static void setRedGammaRamp(int[] redTable)
+	{
+		setGammaRamp(redTable, null, null);
+	}
+
+	/**
+	* SDL_SetGammaRamp(greenTable, null, null)
+	**/
+	public static void setGreenGammaRamp(int[] greenTable)
+	{
+		setGammaRamp(null, greenTable, null);
+	}
+
+	/**
+	* SDL_SetGammaRamp(blueTable, null, null)
+	**/
+	public static void setBlueGammaRamp(int[] blueTable)
+	{
+		setGammaRamp(null, null, blueTable);
+	}
+
 	/**
 	* SDL_GetGammaRamp(redtable, NULL, NULL)
 	**/
