@@ -153,7 +153,9 @@ public class Surface implements VideoConstants
 
 	public native void setPalette(Color[] palette);
 
-	public Color[] getPalette()
+	public native void setPalette(Palette palette);
+
+	public Palette getPalette()
 	{
 		return this.getPixelFormat().getPalette();
 	}
