@@ -1,6 +1,7 @@
 #include "sdl4gcj/video/Surface.h"
 #include "sdl4gcj/video/PixelFormat.h"
 #include "sdl4gcj/video/Color.h"
+#include "sdl4gcj/video/Palette.h"
 #include "sdl4gcj/SDLException.h"
 
 #include <gcj/cni.h>
@@ -378,6 +379,22 @@ Surface::setPalette (JArray< Color *> *palette)
 	return ;
 }
 
+void 
+Surface::setPalette (Palette *palette)
+{
+	if (this->implementation == NULL) throw createFreedSurfaceException();
+	SDL_Surface* nativeSurface = (SDL_Surface*)this->implementation;
+
+	if (nativeSurface->format->palette != NULL)
+	{
+		SDL_Color* nativeColors = (SDL_Color*)palette->colors;
+		int ncolors = palette->getSize();
+		ncolors = ncolors <= 256 ? ncolors : 256;
+		SDL_SetColors(nativeSurface, nativeColors, 0, ncolors);
+	}
+	return ;
+}
+
 JArray<jbyte>*
 Surface::getPixels()
 {
